==> ugene_1.3.3%2Brepack.orig.tar.gz: ugene-1.3.3/src/core/src/util_ov_annotated_dna/PanViewRows.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef  _GB2_PAN_VIEW_ROWS_H_
#define  _GB2_PAN_VIEW_ROWS_H_

#include <core_api/LRegion.h>

#include <QtCore/QString>
#include <QtCore/QMap>
#include <QtCore/QList>

namespace GB2 {

class Annotation;

class PVRowData {
public:
	PVRowData(const QString& _key) : key(_key), rowNum(-1), uptodate(true){}

	QString key;
    int rowNum;
    QList<LRegion> ranges;
    QList<Annotation*> annotations;
    bool uptodate;
};

class PVRowsManager {
public:    
	PVRowsManager() {}
    ~PVRowsManager();

    int addAnnotation(Annotation* f, const QString& key);
    void removeAnnotation(Annotation* f);
    
	int getNumRows() const;
    int getAnnotationRow(Annotation* f);

    bool contains(const QString& key) const;

    void resort();
    void clear();
    
	const QString& getRowKey(int rowNum) const;
	int getNumAnnotationsInRow(int rowNum) const;

private:
    bool isUpToDate() const;
    bool addToRow(Annotation* f, PVRowData* row);
    bool fitToRow(PVRowData* row, const LRegion& region);

    QList<PVRowData*> rows;
    QMap<Annotation*, PVRowData*> rowByAnnotaion;
};


} // namespace

#endif

==> ugene_1.7.1%2Brepack.orig.tar.gz: ugene-1.7.1/src/core/src/util_ov_annotated_dna/PanViewRows.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef  _GB2_PAN_VIEW_ROWS_H_
#define  _GB2_PAN_VIEW_ROWS_H_

#include <core_api/LRegion.h>

#include <QtCore/QString>
#include <QtCore/QMap>
#include <QtCore/QList>

namespace GB2 {

class Annotation;

class PVRowData {
public:
	PVRowData(const QString& _key) : key(_key){}

    bool fitToRow(const QList<LRegion>& locations);

	QString key;
    //invariant: keep the ranges in ascending order
    QList<LRegion> ranges;
    QList<Annotation*> annotations;
};

class PVRowsManager {
public:    
	PVRowsManager() {}
    ~PVRowsManager();
    void clear();

    void addAnnotation(Annotation* f, const QString& key);
    void removeAnnotation(Annotation* f);

    bool contains(const QString& key) const;
    int getNumRows() const {return rows.size();}
    PVRowData* getRow(int row) const;
    int getAnnotationRowIdx(Annotation* a) const;
    PVRowData* getAnnotationRow(Annotation* a) const {return rowByAnnotation.value(a, NULL);}
    
	const QString& getRowKey(int rowNum) const;
	int getNumAnnotationsInRow(int rowNum) const;

private:
    QList<PVRowData*> rows;
    QMap<Annotation*, PVRowData*> rowByAnnotation;
};


} // namespace

#endif
